@@ -26,7 +26,7 @@ use serde_with::{serde_as, skip_serializing_none};
 pub mod errors;
 pub mod v1beta1;
 
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TypeMeta {
     pub kind: Option<String>,
