@@ -17,6 +17,13 @@ impl Volume {
             ..Self::default()
         }
     }
+
+    pub fn device_name(self, device_name: impl ToString) -> Self {
+        Self {
+            device_name: Some(device_name.to_string()),
+            ..self
+        }
+    }
 }
 
 impl Default for VolumeType {
